@@ -141,12 +141,13 @@ set_relation (GtkWidget *widget, GtkLabel *label)
 
 	aobject = gtk_widget_get_accessible (widget);
 
-	/* return if gail is not loaded */
-	g_return_if_fail (GTK_IS_ACCESSIBLE (aobject));
-
 	/* Set the ATK_RELATION_LABEL_FOR relation */
 	gtk_label_set_mnemonic_widget (label, widget);
 
+	/* return if gail is not loaded */
+	if ( ! GTK_IS_ACCESSIBLE (aobject))
+		return;
+
 	targets [0] = gtk_widget_get_accessible (GTK_WIDGET (label));
 
 	relation_set = atk_object_ref_relation_set (aobject);
@@ -613,7 +614,7 @@ fish_properties_apply (GtkDialog *pb, Fish *fish)
 }
 
 static void
-phelp ()
+phelp (void)
 {
 	GError *error = NULL;
 
@@ -674,7 +675,6 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gint           frames;
 	gdouble        speed;
 	gboolean       rotate;
-	GtkWidget     *notebook;
 	GtkWidget     *apply_button;
 
 	if (fish->pb != NULL) {
@@ -701,21 +701,21 @@ display_properties_dialog (BonoboUIComponent *uic,
 				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, 
 				GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	gtk_window_set_wmclass (GTK_WINDOW (fish->pb), "fish", "Fish");
+
+	gtk_dialog_set_default_response (GTK_DIALOG (fish->pb), GTK_RESPONSE_OK);
+
 	gtk_window_set_title (GTK_WINDOW (fish->pb),
 			      _("GNOME Fish Preferences"));
 	gnome_window_icon_set_from_file (GTK_WINDOW (fish->pb),
 					 GNOME_ICONDIR "/gnome-fish.png");
 
-	notebook = gtk_notebook_new ();
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->pb)->vbox), 
-				notebook, TRUE, TRUE, 0);
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	w = gtk_label_new (_("Your GNOME Fish's Name:"));
+	w = gtk_label_new_with_mnemonic (_("_Name of GNOME fish:"));
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	e = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY(e), name);
@@ -732,7 +732,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	l = gtk_label_new (_("The Animation Filename:"));
+	l = gtk_label_new_with_mnemonic (_("_Animation filename:"));
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
 	w = gnome_pixmap_entry_new ("fish_animation", _("Browse"), TRUE);
 	gtk_box_pack_start (GTK_BOX (hbox), w, TRUE, TRUE, 0);
@@ -750,7 +750,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	w = gtk_label_new (_("Command to execute when fish is clicked:"));
+	w = gtk_label_new_with_mnemonic (_("Command to _execute when fish is clicked:"));
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	e = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (e), command);
@@ -767,7 +767,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	w = gtk_label_new (_("Frames In Animation:"));
+	w = gtk_label_new_with_mnemonic (_("Frame_s in animation:"));
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	adj = (GtkAdjustment *) gtk_adjustment_new (frames, 1.0, 255.0, 1.0, 5.0, 0.0);
 	e = gtk_spin_button_new (adj, 0, 0);
@@ -785,7 +785,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	w = gtk_label_new (_("Pause per frame (s):"));
+	w = gtk_label_new_with_mnemonic (_("Pause _per frame (s):"));
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	adj = (GtkAdjustment *) gtk_adjustment_new (speed, 0.1, 10.0, 0.1, 1.0, 0.0);
 	e = gtk_spin_button_new (adj, 0, 2);
@@ -800,7 +800,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 				   GTK_SIGNAL_FUNC (changed_cb),
 				   GTK_OBJECT (apply_button));
 
-	w = gtk_check_button_new_with_label (_("Rotate on vertical panels"));
+	w = gtk_check_button_new_with_mnemonic (_("_Rotate on vertical panels"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), rotate);
 	gtk_signal_connect_object (GTK_OBJECT (w),
 				   "toggled",
@@ -810,9 +810,8 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gtk_object_set_data (GTK_OBJECT (fish->pb), "rotate", w);
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
-	gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-					vbox,
-					gtk_label_new (_("Fish")));
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->pb)->vbox), 
+	                    vbox, TRUE, TRUE, 0);
 
 	gtk_signal_connect (GTK_OBJECT(fish->pb),
 			    "destroy",
@@ -861,9 +860,8 @@ insert_text (Fish *fish, const char *text)
 
 	gtk_text_buffer_get_iter_at_offset (fish->fortune_buffer, &iter, -1);
 
-	gtk_text_buffer_insert_with_tags_by_name (fish->fortune_buffer, &iter,
-						  text, -1,
-						  "monospace", NULL);
+	gtk_text_buffer_insert (fish->fortune_buffer, &iter,
+				text, -1);
 }
 
 static void
@@ -898,7 +896,7 @@ static void
 update_fortune_dialog (Fish *fish)
 {
 	char *fortune_command;
-	FILE *fp;
+	gchar *output = NULL;
 
 	if ( fish->fortune_dialog == NULL ) {
 		GtkWidget *view;
@@ -911,6 +909,9 @@ update_fortune_dialog (Fish *fish)
 						     GTK_STOCK_CLOSE,
 						     GTK_RESPONSE_CLOSE,
 						     NULL);
+
+		gtk_dialog_set_default_response (GTK_DIALOG (fish->fortune_dialog), GTK_RESPONSE_CLOSE);
+
 		g_signal_connect (G_OBJECT (fish->fortune_dialog), "delete_event",
 				  G_CALLBACK (delete_event), NULL);
 		g_signal_connect (G_OBJECT (fish->fortune_dialog), "response",
@@ -931,11 +932,6 @@ update_fortune_dialog (Fish *fish)
 		fish->fortune_buffer =
 			gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
-		gtk_text_buffer_create_tag (fish->fortune_buffer, "monospace",
-					    "family", "monospace",
-					    NULL);
-
-
 		sw = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 						GTK_POLICY_AUTOMATIC,
@@ -949,11 +945,11 @@ update_fortune_dialog (Fish *fish)
 
 		fish->fortune_label = gtk_label_new ("");
 
-		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (fish->fortune_dialog)->vbox), 
+		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
 				    fish->fortune_label,
 				    FALSE, FALSE, GNOME_PAD);
 
-		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (fish->fortune_dialog)->vbox), 
+		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fish->fortune_dialog)->vbox), 
 				    sw,
 				    TRUE, TRUE, GNOME_PAD);
 
@@ -967,20 +963,14 @@ update_fortune_dialog (Fish *fish)
 
 	text_clear (fish);
 
-	fp = NULL;
-
 	fortune_command = fish_locate_fortune_command (fish);
-	if (fortune_command != NULL) {
-		fp = popen (fortune_command, "r");
-	}
+
+	g_spawn_command_line_sync (fortune_command, &output, NULL, NULL, NULL);
+	
 	g_free (fortune_command);
 
-	if (fp != NULL) {
-		char buf[2048];
-		while (fgets (buf, 2048, fp) != NULL) {
-			insert_text (fish, buf);
-		}
-		pclose (fp);
+	if (output) {
+		insert_text (fish, output);
 	} else {
 		insert_text (fish, 
 			     _("You do not have fortune installed "
@@ -988,6 +978,7 @@ update_fortune_dialog (Fish *fish)
 			       "to run.\n\nPlease refer to fish "
 			       "properties dialog."));
 	}
+
 }
 
 static gboolean 
@@ -1067,11 +1058,18 @@ create_fish_widget(Fish *fish)
 		GTK_WIDGET (fish->darea)->requisition.height =
 							fish->h / frames;
 		gtk_widget_queue_resize (GTK_WIDGET (fish->darea));
+		gtk_widget_set_usize (fish->darea,
+				      fish->w,
+				      fish->h / frames);
 	} else {
 		GTK_WIDGET (fish->darea)->requisition.width =
 							fish->h / frames;
 		GTK_WIDGET (fish->darea)->requisition.width = fish->w;
+
 		gtk_widget_queue_resize (GTK_WIDGET (fish->darea));
+		gtk_widget_set_usize (fish->darea,
+				      fish->w / frames,
+				      fish->h);
 	}
 
 	gtk_widget_set_events(fish->darea, gtk_widget_get_events(fish->darea) |
@@ -1089,8 +1087,8 @@ create_fish_widget(Fish *fish)
         fish->timeout_id = gtk_timeout_add (speed * 1000, fish_timeout, fish);
 
         gtk_container_add(GTK_CONTAINER(fish->frame),fish->darea);
-
-	gtk_widget_pop_colormap ();
+        
+        gtk_widget_pop_colormap ();
 }
 
 static void
@@ -1302,7 +1300,7 @@ fish_applet_fill (PanelApplet *applet)
 	load_image_file (fish);
 
 	create_fish_widget (fish);
-
+	
 	set_wanda_day ();
 
 	gtk_container_add (GTK_CONTAINER (fish->applet), fish->frame);
@@ -1312,6 +1310,8 @@ fish_applet_fill (PanelApplet *applet)
 	gtk_widget_show_all (GTK_WIDGET (fish->frame));
 
 	gtk_widget_show (GTK_WIDGET (fish->applet));
+	
+	setup_size (fish);
 
 	panel_applet_setup_menu_from_file (PANEL_APPLET (fish->applet),
 				 NULL,
