@@ -521,15 +521,28 @@ panel_applet_create_menu (AppletInfo *info)
 	g_signal_connect (menu, "deactivate",
 			  G_CALLBACK (applet_menu_deactivate), info);
 
+	if (info->user_menu) {
+		for (l = info->user_menu; l; l = l->next) {
+			AppletUserMenu *user_menu = (AppletUserMenu *)l->data;
+
+			add_to_submenus (info, "", user_menu->name, user_menu, 
+					 menu, info->user_menu);
+		}
+	}
+
 	if (!commie_mode) {
 		GtkWidget *image;
 
+		menuitem = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		gtk_widget_show (menuitem);
+
 		menuitem = gtk_image_menu_item_new ();
 
 		image = gtk_image_new_from_stock (GTK_STOCK_REMOVE,
 						  GTK_ICON_SIZE_MENU);
 
-		setup_menuitem (menuitem, image , _("Remove from panel"));
+		setup_menuitem (menuitem, image , _("Remove From Panel"));
 
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (applet_remove_callback), info);
@@ -548,20 +561,6 @@ panel_applet_create_menu (AppletInfo *info)
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	}
 
-	if (!info->user_menu)
-		return menu;
-
-	menuitem = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	gtk_widget_show (menuitem);
-
-	for (l = info->user_menu; l; l = l->next) {
-		AppletUserMenu *user_menu = (AppletUserMenu *)l->data;
-
-		add_to_submenus (info, "", user_menu->name, user_menu, 
-				 menu, info->user_menu);
-	}
-
 	return menu;
 }
 
@@ -679,12 +678,12 @@ applet_destroy (GtkWidget *w, AppletInfo *info)
 
 	if (info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
-		g_assert(drawer);
-		if(drawer->drawer) {
-			GtkWidget *dw = drawer->drawer;
+
+		if (drawer->drawer) {
+			PANEL_WIDGET (BASEP_WIDGET (drawer->drawer)->panel)->master_widget = NULL;
+
+			gtk_widget_destroy (drawer->drawer);
 			drawer->drawer = NULL;
-			PANEL_WIDGET(BASEP_WIDGET(dw)->panel)->master_widget = NULL;
-			gtk_widget_destroy(dw);
 		}
 	} else if (info->type == APPLET_LAUNCHER) {
 		Launcher    *launcher = info->data;
@@ -751,7 +750,7 @@ typedef struct {
 	PanelWidget *panel_widget;
 	int          position;
 	char        *unique_id;
-	guint        panel_destroy_id;
+	gulong       destroy_handler;
 } PanelAppletToLoad;
 
 static GSList *panel_applets_to_load = NULL;
@@ -759,15 +758,17 @@ static GSList *panel_applets_to_load = NULL;
 static void
 whack_applet_to_load (PanelAppletToLoad *applet)
 {
-	if (applet->panel_destroy_id > 0)
-		g_source_remove (applet->panel_destroy_id);
-	applet->panel_destroy_id = 0;
+	if (applet->destroy_handler > 0)
+		g_signal_handler_disconnect (applet->panel_widget,
+					     applet->destroy_handler);
+	applet->destroy_handler = 0;
+
 	g_free (applet->unique_id);
 	applet->unique_id = NULL;
+
 	g_free (applet);
 }
 
-
 static gboolean
 panel_applet_load_idle_handler (gpointer dummmy)
 {
@@ -795,7 +796,7 @@ panel_destroyed_while_loading (GtkWidget *panel, gpointer data)
 {
 	PanelAppletToLoad *applet = data;
 
-	applet->panel_destroy_id = 0;
+	applet->destroy_handler = 0;
 
 	panel_applets_to_load =
 		g_slist_remove (panel_applets_to_load, applet);
@@ -862,13 +863,13 @@ panel_applet_load_from_unique_id (AppletType   type,
 
 		applet = g_new0 (PanelAppletToLoad, 1);
 
-		applet->panel_widget = panel_widget;
-		applet->position     = position;
-		applet->unique_id    = g_strdup (unique_id);
-		applet->panel_destroy_id = g_signal_connect
-			(G_OBJECT (panel_widget), "destroy",
-			 G_CALLBACK (panel_destroyed_while_loading),
-			 applet);
+		applet->panel_widget    = panel_widget;
+		applet->position        = position;
+		applet->unique_id       = g_strdup (unique_id);
+		applet->destroy_handler =
+				g_signal_connect (panel_widget, "destroy",
+						  G_CALLBACK (panel_destroyed_while_loading),
+						  applet);
 
 		if (!panel_applets_to_load)
 			g_idle_add (panel_applet_load_idle_handler, NULL);
@@ -1106,6 +1107,8 @@ panel_applet_register (GtkWidget      *applet,
 		g_object_set_data (G_OBJECT (applet),
 				   PANEL_APPLET_ASSOC_PANEL_KEY, assoc_panel);
 		assoc_panel->master_widget = applet;
+		g_object_add_weak_pointer (
+			G_OBJECT (applet), (gpointer *) &assoc_panel->master_widget);
 	}
 
 	g_object_set_data (G_OBJECT (applet),
