@@ -122,8 +122,8 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 		g_signal_new	("move_focus_out",
 				G_TYPE_FROM_CLASS (object_class),
 				G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-				G_STRUCT_OFFSET (FoobarWidgetClass, move_focus_out),				NULL,
-                                NULL,
+				G_STRUCT_OFFSET (FoobarWidgetClass, move_focus_out),
+				NULL, NULL,
                                 panel_marshal_VOID__VOID,
 				G_TYPE_NONE,
 				0);
@@ -187,6 +187,17 @@ foobar_enter_notify (GtkWidget *widget,
 	return FALSE;
 }
 
+static void
+foobar_search (GtkWidget *widget,
+	       gpointer   data)
+{
+	char *argv[2] = {"gnome-search-tool", NULL};
+
+	if (gnome_execute_async (g_get_home_dir (), 1, argv) < 0)
+		panel_error_dialog ("cannot_exec_gnome-search-tool",
+				    _("Cannot execute gnome-search-tool"));
+}
+
 static void
 append_actions_menu (GtkWidget *menu_bar)
 {
@@ -205,8 +216,20 @@ append_actions_menu (GtkWidget *menu_bar)
 			  G_CALLBACK (show_run_dialog), 0);
 	setup_internal_applet_drag (item, "RUN:NEW");
 
-	/* FIXME: search */
-	/* FIXME: shutdown or reboot */
+	if (panel_is_program_in_path  ("gnome-search-tool")) {
+		item = pixmap_menu_item_new (
+				_("Search for Files..."), "gnome-searchtool.png", FALSE);
+
+		gtk_tooltips_set_tip (panel_tooltips, item,
+				      _("Find files, folders, and documents "
+				        "on your computer"),
+				      NULL);
+
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		g_signal_connect (item, "activate",
+				  G_CALLBACK (foobar_search), 0);
+	}
+
 
 	if (panel_is_program_in_path  ("xscreensaver")) {
 		item = pixmap_menu_item_new (_("Lock Display"), 
@@ -232,6 +255,8 @@ append_actions_menu (GtkWidget *menu_bar)
 			  G_CALLBACK (panel_quit), 0);
 	setup_internal_applet_drag (item, "LOGOUT:NEW");
 
+	/* FIXME: shutdown or reboot */
+
 	item = gtk_menu_item_new_with_label (_("Actions"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu_bar), item);
@@ -303,13 +328,9 @@ set_the_task_submenu (FoobarWidget *foo, GtkWidget *item)
 static void
 focus_window (GtkWidget *w, WnckWindow *window)
 {
-	WnckScreen *screen = wnck_screen_get (0 /* FIXME screen number */);
-	WnckWorkspace *wspace = wnck_screen_get_active_workspace (screen);
-
-	if (wspace != NULL)
-		wnck_window_move_to_workspace (window, wspace);
 	if (wnck_window_is_minimized (window)) 
 		wnck_window_unminimize (window);
+
 	wnck_window_activate (window);
 }
 
@@ -453,12 +474,6 @@ create_task_menu (GtkWidget *w, gpointer data)
 
 	if (GTK_WIDGET_VISIBLE (foo->task_menu))
 		our_gtk_menu_position (GTK_MENU (foo->task_menu));
-
-	/* Owen: don't read the next line */
-#if 0
-	GTK_MENU_SHELL (foo->task_menu)->active = 1;
-	our_gtk_menu_position (GTK_MENU (foo->task_menu));
-#endif
 }
 
 static void
@@ -653,7 +668,6 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *align;
-	GList     *focus_chain = NULL;
 	char      *path;
 
 	window = GTK_WINDOW (foo);
@@ -736,6 +750,8 @@ foobar_widget_instance_init (FoobarWidget *foo)
 
 	g_object_set_data (G_OBJECT (menu_bar), "menu_panel", foo->panel);
 
+	add_atk_name_desc (foo->panel, _("Base Panel"), _("Gnome Base Panel"));
+
 	path = panel_pixmap_discovery ("panel-corner-right.png", FALSE /* fallback */);
 	if (path != NULL) {
 		bufmap = gtk_image_new_from_file (path);
@@ -753,18 +769,6 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	gtk_box_pack_end (GTK_BOX (foo->hbox), task_bar, FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (foo), foo->ebox);
 
-#if 0
-		{
-			GList *focus_chain = NULL;
-
-			focus_chain = g_list_prepend (focus_chain, task_bar);
-			focus_chain = g_list_prepend (focus_chain, foo->panel);
-			focus_chain = g_list_prepend (focus_chain, menu_bar);
-			gtk_container_set_focus_chain (GTK_CONTAINER (foo->hbox), focus_chain);
-			g_list_free (focus_chain);
-		}
-#endif
-
 	gtk_widget_show_all (foo->ebox);
 }
 
