@@ -164,6 +164,7 @@ kill_free_drawers (void)
 
 static const struct poptOption options[] = {
   {"profile", '\0', POPT_ARG_STRING, &profile_name, 0, N_("Specify a profile name to load"), NULL},
+  POPT_AUTOHELP
   {NULL, '\0', 0, NULL, 0}
 };
 
@@ -204,13 +205,15 @@ main(int argc, char **argv)
 	g_signal_connect (client, "die",
 			  G_CALLBACK (panel_session_die), NULL);
 
+	panel_register_window_icon ();
+
 	panel_tooltips = gtk_tooltips_new ();
 
 	xstuff_init ();
 	multiscreen_init ();
 
 	panel_gconf_add_dir ("/apps/panel/global");
-	panel_gconf_add_dir ("/desktop/gnome/menus");
+	panel_gconf_add_dir ("/desktop/gnome/interface");
 	panel_gconf_notify_add ("/apps/panel/global", panel_global_config_notify, NULL);
 
 	status_applet_create_offscreen ();
