@@ -33,6 +33,7 @@
 
 #include "panel-applet-frame.h"
 #include "panel-gconf.h"
+#include "panel-util.h"
 #include "session.h"
 #include "applet.h"
 #include "panel-marshal.h"
@@ -192,6 +193,38 @@ panel_applet_frame_get_expand_flags (PanelAppletFrame *frame,
 	*expand_minor = retval & (1 << 1);
 }
 
+
+int *
+panel_applet_frame_get_size_hints (PanelAppletFrame *frame,
+				   int              *n_elements)
+{
+	CORBA_any *value;
+	CORBA_sequence_CORBA_long *seq;
+	int *size_hints;
+	int i;
+
+	*n_elements = 0;
+	value = bonobo_pbclient_get_value (frame->priv->property_bag,
+					   "panel-applet-size-hints",
+					   TC_CORBA_sequence_CORBA_long,
+					   NULL);
+	
+	if (value == NULL)
+		return NULL;
+
+	seq = value->_value;
+
+	*n_elements = seq->_length;
+	size_hints = g_new (int, seq->_length);
+	for (i = 0; i < seq->_length; i++) {
+		size_hints[i] = seq->_buffer[i];
+	}
+	
+	CORBA_free (value);
+	
+	return size_hints;
+}
+
 void
 panel_applet_frame_change_orient (PanelAppletFrame *frame,
 				  PanelOrient       orient)
@@ -568,26 +601,15 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 	g_free (moniker);
 
 	if (BONOBO_EX (&ev)) {
-		GtkWidget *dialog;
 		char *err = bonobo_exception_get_text (&ev);
-		char *txt = g_strdup_printf (
-			_("There was a problem loading applet '%s': %s"),
+		panel_error_dialog
+			("problem_loading_applet",
+			 _("<b>There was a problem loading applet '%s'</b>\n\n"
+			   "Details: %s"),
 			  iid, err);
-	
-		dialog = gtk_message_dialog_new (
-			NULL,
-			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_ERROR,
-			GTK_BUTTONS_OK,
-			txt);
-		g_signal_connect (dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy), NULL);
-	
-		gtk_widget_show (dialog);
 
 		CORBA_exception_free (&ev);
 
-		g_free (txt);
 		g_free (err);
 
 		return NULL;
