@@ -45,7 +45,6 @@
 #include "panel-gconf.h"
 #include "session.h"
 #include "status.h"
-#include "swallow.h"
 #include "panel-applet-frame.h"
 #include "global-keys.h"
 
@@ -160,12 +159,6 @@ static GConfEnumStringPair panel_speed_type_enum_map [] = {
 	{ PANEL_SPEED_FAST,   "panel-speed-fast" },
 };
 
-static GConfEnumStringPair panel_layer_type_enum_map [] = {
-	{ LAYER_NORMAL, "panel-normal-layer" },
-	{ LAYER_BELOW, "panel-below-layer" },
-	{ LAYER_ABOVE, "panel-above-layer" },
-};
-
 static void
 change_window_cursor(GdkWindow *window, GdkCursorType cursor_type)
 {
@@ -218,17 +211,6 @@ orientation_change (AppletInfo  *info,
 				       (gpointer)basep->panel);
 		}
 		break;
-	case APPLET_SWALLOW: {
-		Swallow *swallow = info->data;
-
-		if (panel->orient == GTK_ORIENTATION_VERTICAL)
-			set_swallow_applet_orient (swallow,
-						   SWALLOW_VERTICAL);
-		else
-			set_swallow_applet_orient (swallow,
-						   SWALLOW_HORIZONTAL);
-		}
-		break;
 	case APPLET_STATUS: {
 		StatusApplet *status = info->data;
 
@@ -571,22 +553,15 @@ panel_remove_applets (PanelWidget *panel)
 	GList *l;
 
 	for (l = panel->applet_list; l; l = l->next) {
-		AppletData *ad = l->data;
+		AppletData *applet_data = l->data;
 		AppletInfo *info;
 
-		info = g_object_get_data (G_OBJECT (ad->applet),
-					  "applet_info");
+		info = g_object_get_data (
+				G_OBJECT (applet_data->applet), "applet_info");
 
-		if (info->type == APPLET_BONOBO) {
-			PanelAppletFrame *frame = info->data;
-
-			panel_applet_frame_set_clean_remove
-				(PANEL_APPLET_FRAME (frame), TRUE);
-		} else if (info->type == APPLET_SWALLOW) {
-			Swallow *swallow = info->data;
-
-			swallow->clean_remove = TRUE;
-		}
+		if (info && info->type == APPLET_BONOBO)
+			panel_applet_frame_set_clean_remove (
+					PANEL_APPLET_FRAME (info->data), TRUE);
 	}
 }
 
@@ -605,18 +580,16 @@ panel_destroy (GtkWidget *widget, gpointer data)
 		
 	kill_config_dialog(widget);
 
-	if (DRAWER_IS_WIDGET(widget)) {
-		GtkWidget *master_widget = panel->master_widget;
+	if (DRAWER_IS_WIDGET (widget)) {
+		if (panel->master_widget) {
+			AppletInfo *info;
 
-		if (master_widget != NULL) {
-			AppletInfo *info =
-				g_object_get_data (G_OBJECT (master_widget),
-						   "applet_info");
-			Drawer *drawer = info->data;
-			drawer->drawer = NULL;
+			info = g_object_get_data (
+					G_OBJECT (panel->master_widget), "applet_info");
+			((Drawer *) info->data)->drawer = NULL;
 			panel_applet_clean (info);
-			g_object_set_data (G_OBJECT (master_widget),
-					   "applet_info", NULL);
+
+			g_assert (panel->master_widget == NULL);
 		}
 	} else if ((BASEP_IS_WIDGET(widget)
 		    && !DRAWER_IS_WIDGET(widget))
@@ -1273,10 +1246,9 @@ drop_internal_applet (PanelWidget *panel, int pos, const char *applet_type,
 		return;
 
 	if (sscanf (applet_type, "MENU:%d", &applet_num) == 1 ||
-	    sscanf (applet_type, "DRAWER:%d", &applet_num) == 1 ||
-	    sscanf (applet_type, "SWALLOW:%d", &applet_num) == 1) {
+	    sscanf (applet_type, "DRAWER:%d", &applet_num) == 1) {
 		if (action != GDK_ACTION_MOVE)
-			g_warning ("Only MOVE supported for menus/drawers/swallows");
+			g_warning ("Only MOVE supported for menus/drawers");
 		move_applet (panel, pos, applet_num);
 
 	} else if (strncmp (applet_type, "MENU:", strlen("MENU:")) == 0) {
@@ -1303,9 +1275,6 @@ drop_internal_applet (PanelWidget *panel, int pos, const char *applet_type,
 		load_lock_applet (panel, pos, TRUE, NULL);
 		remove_applet = TRUE;
 
-	} else if (strcmp (applet_type, "SWALLOW:ASK") == 0) {
-		ask_about_swallowing(panel, pos, TRUE);
-
 	} else if(strcmp(applet_type,"LAUNCHER:ASK")==0) {
 		ask_about_launcher(NULL, panel, pos, TRUE);
 
@@ -1963,12 +1932,6 @@ panel_save_global_config (void)
 	full_key = panel_gconf_global_key ("auto_raise_panel");
 	gconf_change_set_set_bool (change_set, full_key, global_config.autoraise);
 
-	full_key = panel_gconf_global_key ("panel_window_layer");
-	gconf_change_set_set_string (
-			change_set, full_key,
-			gconf_enum_to_string (panel_layer_type_enum_map, global_config.layer));
-
-
 	full_key = panel_gconf_global_key ("drawer_autoclose");
 	gconf_change_set_set_bool (change_set, full_key, global_config.drawer_auto_close);
 
@@ -1986,7 +1949,6 @@ panel_save_global_config (void)
 void
 panel_apply_global_config (void)
 {
-	static int layer_old = -1;
 	static int menu_flags_old = -1;
 	static int old_menu_check = -1;
 	GSList *li;
@@ -2048,19 +2010,6 @@ panel_apply_global_config (void)
 		}
 	}
 
-	if (layer_old != global_config.layer) {
-		 for (li = panel_list; li != NULL; li = li->next) {
-			PanelData *pd = li->data;
-			if ( ! GTK_WIDGET_REALIZED (pd->panel))
-				continue;
-			if (BASEP_IS_WIDGET (pd->panel))
-				basep_widget_update_winhints (BASEP_WIDGET (pd->panel));
-			else if (FOOBAR_IS_WIDGET (pd->panel))
-				foobar_widget_update_winhints (FOOBAR_WIDGET (pd->panel));
-		}
-	}
-	layer_old = global_config.layer;
-	
 	for (li = panel_list; li != NULL; li = li->next) {
 		PanelData *pd = li->data;
 		if (BASEP_IS_WIDGET (pd->panel)) {
@@ -2285,7 +2234,7 @@ panel_load_panels_from_gconf (void)
 			g_free (tmp_str);
 
 			tmp_str = panel_get_string (profile, panel_id,
-						    "panel-align", "panel-alignment-left");
+						    "panel_align", "panel-alignment-left");
 			gconf_string_to_enum (
 				panel_alignment_type_enum_map, tmp_str, (gint *) &align);
 			g_free (tmp_str);
@@ -2318,12 +2267,12 @@ panel_load_panels_from_gconf (void)
 			g_free (tmp_str);
 
 			tmp_str = panel_get_string (profile, panel_id,
-						    "panel-anchor", "panel-anchor-left");
+						    "panel_anchor", "panel-anchor-left");
 			gconf_string_to_enum (
 				panel_anchor_type_enum_map, tmp_str, (gint *) &anchor);
 			g_free (tmp_str);
 			
-			offset = panel_get_int (profile, panel_id, "panel-offset", 0);
+			offset = panel_get_int (profile, panel_id, "panel_offset", 0);
 	
 			panel = sliding_widget_new (panel_id,
 						    screen,
@@ -2346,7 +2295,7 @@ panel_load_panels_from_gconf (void)
 			int orient;
 
 			tmp_str = panel_get_string (profile, panel_id,
-						    "panel-orient", "panel-orient-up");
+						    "panel_orient", "panel-orient-up");
 			gconf_string_to_enum (
 				panel_orient_type_enum_map, tmp_str, (gint *) &orient);
 			g_free (tmp_str);
@@ -2370,13 +2319,13 @@ panel_load_panels_from_gconf (void)
 			int            x, y;
 
 			tmp_str = panel_get_string (profile, panel_id,
-						    "panel-orient ", "panel-orientation-horizontal");
+						    "panel_orient", "panel-orientation-horizontal");
 			gconf_string_to_enum (
 				panel_orientation_type_enum_map, tmp_str, (gint *) &orient);
 			g_free (tmp_str);
 
-			x = panel_get_int (profile, panel_id, "panel-x-position", 0);
-			y = panel_get_int (profile, panel_id, "panel-y-position", 0);
+			x = panel_get_int (profile, panel_id, "panel_x_position", 0);
+			y = panel_get_int (profile, panel_id, "panel_y_position", 0);
 			
 			panel = floating_widget_new (panel_id,
 						     screen,
@@ -2395,18 +2344,8 @@ panel_load_panels_from_gconf (void)
 						     &back_color);
 			}
 			break;
-		case FOOBAR_PANEL: {
-			char *timestring;
-
+		case FOOBAR_PANEL:
 			panel = foobar_widget_new (panel_id, screen);
-
-			timestring = panel_get_string (profile, panel_id,
-						       "clock_format", _("%I:%M:%S %p"));
-			if (timestring) {
-				foobar_widget_set_clock_format (FOOBAR_WIDGET (panel), timestring);
-				g_free (timestring);
-			}
-			}
 			break;
 		default:
 			panel = NULL;
@@ -2546,41 +2485,38 @@ panel_save_to_gconf (PanelData *pd)
 	switch (pd->type) {
 	case ALIGNED_PANEL:
 		panel_set_string (profile, panel->unique_id,
-				  "panel-align", 
+				  "panel_align", 
 				  gconf_enum_to_string (panel_alignment_type_enum_map,
 							ALIGNED_POS (basep->pos)->align));
 		break;
 	case SLIDING_PANEL:
 		panel_set_int (profile, panel->unique_id,
-			       "panel-offset", SLIDING_POS (basep->pos)->offset);
+			       "panel_offset", SLIDING_POS (basep->pos)->offset);
 
 		panel_set_string (profile, panel->unique_id,
-				  "panel-anchor", 
+				  "panel_anchor", 
 				  gconf_enum_to_string (panel_anchor_type_enum_map,
 							SLIDING_POS (basep->pos)->anchor));
 		break;
 	case FLOATING_PANEL:
 		panel_set_string (profile, panel->unique_id,
-				  "panel-orient", 
+				  "panel_orient", 
 				  gconf_enum_to_string (panel_orientation_type_enum_map,
-							PANEL_WIDGET (basep->pos)->orient));
+							PANEL_WIDGET (basep->panel)->orient));
 
 		panel_set_int (profile, panel->unique_id,
-			       "panel-x-position", FLOATING_POS (basep->pos)->x);
+			       "panel_x_position", FLOATING_POS (basep->pos)->x);
 
 		panel_set_int (profile, panel->unique_id,
-			       "panel-y-position", FLOATING_POS (basep->pos)->y);
+			       "panel_y_position", FLOATING_POS (basep->pos)->y);
 		break;
 	case DRAWER_PANEL:
 		panel_set_string (profile, panel->unique_id,
-				  "panel-orient", 
+				  "panel_orient", 
 				  gconf_enum_to_string (panel_orient_type_enum_map,
 							DRAWER_POS (basep->pos)->orient));
 		break;
 	case FOOBAR_PANEL:
-		panel_set_string (profile, panel->unique_id,
-				  "clock_format", FOOBAR_WIDGET (pd->panel)->clock_format);
-
 		panel_set_int (profile, panel->unique_id, 
 			       "screen_id", FOOBAR_WIDGET (pd->panel)->screen);
 		break;
